CloudStorage class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getItem(String key, void callback(String? error, [String? result]))
→ CloudStorage
-
A method that receives a value from the cloud storage using the specified key.
key should contain 1-128 characters, only A-Z, a-z, 0-9, _ and - are allowed
In case of an error, the callback function will be called and the first argument
will contain the error. In case of success, the first argument will be null and
the value will be passed as the second argument.
-
getItems(List<String> keys, void callback(String? error, [List<String>? values]))
→ CloudStorage
-
A method that receives values from the cloud storage using the specified keys.
keys should contain 1-128 characters, only A-Z, a-z, 0-9, _ and - are allowed.
In case of an error, the callback function will be called and the first argument
will contain the error. In case of success, the first argument will be null
and the values will be passed as the second argument.
-
getKeys(void callback(String? error, [List<String>? keys]))
→ CloudStorage
-
A method that receives the list of all keys stored in the cloud storage.
In case of an
error, the callback function will be called and the first argument will contain
the error. In case of success, the first argument will be null and the list of keys will be
passed as the second argument.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
removeItem(String key, [void callback(String? error, [bool? removed])?])
→ CloudStorage
-
A method that removes a value from the cloud storage using the specified key.
key should contain 1-128 characters, only A-Z, a-z, 0-9, _ and - are allowed.
If an optional eventHandler parameter was passed, the callback function will be called.
In case of an error, the first argument will contain the error. In case of success,
the first argument will be null and the second argument will be a boolean indicating
whether the value was removed.
-
removeItems(List<String> keys, [void callback(String? error, [bool? removed])?])
→ CloudStorage
-
A method that removes values from the cloud storage using the specified keys.
keys should contain 1-128 characters, only A-Z, a-z, 0-9, _ and - are allowed.
If an optional eventHandler parameter was passed, the callback function will be called.
In case of an error, the first argument will contain the error. In case of success,
the first argument will be null and the second argument will be a boolean indicating
whether the values were removed.
-
setItem(String key, String value, [void callback(String? error, [bool? isStored])?])
→ CloudStorage
-
A method that stores a value in the cloud storage using the specified key.
You can store up to 1024 keys in the cloud storage
key should contain 1-128 characters, only A-Z, a-z, 0-9, _ and - are allowed
value should contain 0-4096 characters.
If an optional eventHandler parameter was passed, the callback function will be called.
In case of an error, the first argument will contain the error.
In case of success, the first argument will be null and the second argument will
be a boolean indicating whether the value was stored.
-
toString()
→ String
-
A string representation of this object.
inherited