getItems method
A method that receives values from the cloud storage using the specified keys.
keys should contain 1-128 characters, only A-Z, a-z, 0-9, _ and - are allowed.
In case of an error, the callback function will be called and the first argument
will contain the error. In case of success, the first argument will be null
and the values will be passed as the second argument.
Implementation
CloudStorage getItems(List<String> keys, void Function(String? error, [List<String>? values]) callback) {
Telegram.WebApp.CloudStorage
.getItems(
keys.map((e) => e.toJS).toList().toJS,
(JSString? error, JSArray<JSString>? values) {
callback(error?.toDart, values?.toDart.map((e) => e.toDart).toList());
}.toJS,
);
return this;
}