getKeys method
A method that receives the list of all keys stored in the cloud storage.
In case of an error, the callback function will be called and the first argument will contain
the error. In case of success, the first argument will be null and the list of keys will be
passed as the second argument.
Implementation
CloudStorage getKeys(void Function(String? error, [List<String>? keys]) callback) {
Telegram.WebApp.CloudStorage
.getKeys(
(JSString? error, JSArray<JSString>? keys) {
callback(error?.toDart, keys?.toDart.map((e) => e.toDart).toList());
}.toJS,
);
return this;
}