removeItems method
A method that removes values from the cloud storage using the specified keys.
keys should contain 1-128 characters, only A-Z, a-z, 0-9, _ and - are allowed.
If an optional eventHandler parameter was passed, the callback function will be called.
In case of an error, the first argument will contain the error. In case of success,
the first argument will be null and the second argument will be a boolean indicating
whether the values were removed.
Implementation
CloudStorage removeItems(List<String> keys, [void Function(String? error, [bool? removed])? callback]) {
Telegram.WebApp.CloudStorage.removeItems(keys.map((e) => e.toJS).toList().toJS, callback?.toJS);
return this;
}