text property
The text to be displayed on the button, 0-64 characters. Required if type is default or destructive. Irrelevant for other types.
Implementation
final String? text;
The text to be displayed on the button, 0-64 characters. Required if type is default or destructive. Irrelevant for other types.
final String? text;